@@ -56,7 +56,7 @@ def read_tabular_data(filename):
     Note: key made lowercase"""
     debug.trace_fmtd(4, "read_tabular_file({f})", f=filename)
     table = {}
-    with open(filename) as f:
+    with system.open_file(filename) as f:
         for (i, line) in enumerate(f):
             line = system.from_utf8(line)
             items = line.split("\t")
@@ -98,11 +98,12 @@ def is_prime(num):
         is_prime_num = (num > 1)
         if not is_prime_num:
             debug.trace_fmt(4, "{n} not prime as less than 3 and not 2.", n=num)
+        return is_prime_num
 
     # Next, make sure not divisible by 2 or 3
     elif ((num % 2 == 0) or (num % 3 == 0)):
         debug.trace_fmt(4, "{n} not prime as divisible by 2 or 3.", n=num)
-        is_prime_num = False
+        return False
 
     # Otherwise, check (6k +/- 1) values to see if divisible by 2 or 3,
     # stopping when value exceeds sqrt(n).
@@ -119,6 +120,24 @@ def is_prime(num):
     return is_prime_num
 
 
+def prime_factorization(num):
+    """Return list of primne factors for NUM"""
+    ## EX: prime_factors(123) => [3, 41]
+    ## EX: prime_factors(127) => [127]
+    i = 2
+    factors = []
+    while i * i <= num:
+        if num % i:
+            i += 1
+        else:
+            num //= i
+            factors.append(i)
+    if num > 1:
+        factors.append(num)
+    debug.trace(6, f"prime_factorization({num}) => factors")
+    return factors
+
+
 def fibonacci(max_num):
     """Returns Fibonacci sequence with numbers less than MAX_NUM"""
     # EX: fibonacci(10) => [0, 1, 1, 2, 3, 5, 8]
@@ -216,8 +235,8 @@ def exactly1(items):
 def string_diff(text1, text2):
     """Return diff-style comparison of TEXT1 and TEXT2 with an empty string used for equality"""
     debug.trace(6, f"string_diff({text1}, {text2})")
-    # EX: string_diff("one\ntwo\nthree\nfour", "one\ntoo\ntree\nfour") => "  one\n- two\n…  ^\n+ too\n…  ^\n- three\n…  -\n+ tree  four\n"
-    
+    # EX: string_diff("one\ntwo\nthree\nfour", "one\ntoo\ntree\nfour") => "  one\n< two\n…  ^\n> too\n…  ^\n< three\n…  -\n> tree\n  four\n"
+
     # Perform comparison
     diff_result = "n/a"
     try:
@@ -226,16 +245,14 @@ def string_diff(text1, text2):
         diff_result = "".join(ndiff(lines1, lines2))
     except:
         system.print_exception_info("string_diff compare")
-    
-    # Convert to diff-style output, using < and > instead of - and +
+
+    # Convert to diff-style output, using:
+    # < and > instead of - and +
+    # … instead of ?
     try:
-        ## TODO:
-        ## diff_result = re.sub(r"^- ", "< ", diff_result, re.MULTILINE)
-        ## diff_result = re.sub(r"^\+ ", "> ", diff_result, re.MULTILINE)
-        ## diff_result = re.sub(r"^\? ", f"{ELLIPSIS} ", diff_result, re.MULTILINE)
-        diff_result = diff_result.replace("- ", "< ", 1).replace("\n- ", "\n< ").   \
-                          replace("+ ", "> ", 1).replace("\n+ ", "\n> ").           \
-                          replace("\n? ", f"\n{ELLIPSIS} ")
+        diff_result = re.sub(r"^- ", "< ", diff_result, flags=re.MULTILINE)
+        diff_result = re.sub(r"^\+ ", "> ", diff_result, flags=re.MULTILINE)
+        diff_result = re.sub(r"^\? ", f"{ELLIPSIS} ", diff_result, flags=re.MULTILINE)
     except:
         system.print_exception_info("string_diff postprocess")
 
